# DeLTA
> **NOTE**
This is version 2 of the DeLTA pipeline. For version 1, please check out branch 'version1'

DeLTA (Deep Learning for Time-lapse Analysis) is a deep learning-based image processing pipeline for segmenting and tracking single cells in time-lapse microscopy movies.

![](https://gitlab.com/dunloplab/delta/-/raw/images/DeLTAexample.gif)

:scroll: To get started check out the documentation at [delta.readthedocs.io](https://delta.readthedocs.io)

:bug: If you encounter bugs or have questions about the software, please use [Gitlab's issue system](https://gitlab.com/dunloplab/delta/-/issues)

For the latest _hotness_ check out the `dev` branch. You can also quickly test DeLTA on our data or your own with Google Colab
for free [here](https://colab.research.google.com/drive/1UL9oXmcJFRBAm0BMQy_DMKg4VHYGgtxZ?usp=sharing)

--------------------------
See also our papers and manuscript for more details:

Version 2 preprint: [O’Connor, O. M., Alnahhas, R. N., Lugagne, J.-B., & Dunlop, M. J. (2021). DeLTA 2.0: A deep learning pipeline for quantifying single-cell spatial and temporal dynamics. _BioRxiv_, 2021.08.10.455795](https://www.biorxiv.org/content/10.1101/2021.08.10.455795v1)

Version 1 paper:
[Lugagne, J.-B., Lin, H., & Dunlop, M. J. (2020). DeLTA: Automated cell segmentation, tracking, and lineage reconstruction using deep learning. _PLOS Computational Biology_, 16(4), e1007673](https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1007673).
